Security Advisories (12)
Mojo::DOM did not correctly parse <script> tags.
Small sessions could be used as part of a brute-force attack to decode the session secret.
A bug in format detection can potentially be exploited for a DoS attack.
Mojo::UserAgent::CookieJar leaks old cookies because of the missing host_only flag on empty domain.
Directory traversal on Windows
Mojo::UserAgent was not checking peer SSL certificates by default.
GET requests with embedded backslashes can be used to access local files on Windows hosts
Context sensitivity of method param could lead to parameter injection attacks.
Mojolicious is vulnerable to cross-site scripting, caused by improper validation of user-supplied input by link_to helper. A remote attacker could exploit this vulnerability using a specially-crafted URL to execute script in a victim's Web browser within the security context of the hosting Web site, once the URL is clicked. An attacker could use this vulnerability to steal the victim's cookie-based authentication credentials.
Directory traversal vulnerability in Path.pm in Mojolicious before 1.16 allows remote attackers to read arbitrary files via a %2f..%2f (encoded slash dot dot slash) in a URI.
Cross-site scripting (XSS) vulnerability in the link_to helper in Mojolicious before 1.12 allows remote attackers to inject arbitrary web script or HTML via unspecified vectors.
Mojolicious versions from 0.999922 for Perl uses a hard coded string, or the application's class name, as a HMAC session secret by default. These predictable default secrets can be exploited to forge session cookies. An attacker who knows or guesses the secret could compute valid HMAC signatures for the session cookie, allowing them to tamper with or hijack another user's session.
- https://github.com/hashcat/hashcat/pull/4090
- https://github.com/mojolicious/mojo/pull/1791
- https://github.com/mojolicious/mojo/pull/2200
- https://medium.com/securing/baking-mojolicious-cookies-revisited-a-case-study-of-solving-security-problems-through-security-by-13da7c225802
- https://metacpan.org/release/SRI/Mojolicious-9.39/source/lib/Mojolicious.pm#L51
- https://www.synacktiv.com/publications/baking-mojolicious-cookies
- https://www.cve.org/CVERecord?id=CVE-2024-58134
NAME
hypnotoad - Hypnotoad HTTP 1.1 And WebSocket Server
SYNOPSIS
hypnotoad myapp.pl
DESCRIPTION
Start Mojolicious and Mojolicious::Lite applications with the Mojo::Server::Hypnotoad web server.
Note that this script is EXPERIMENTAL and might change without warning!
SEE ALSO
Module Install Instructions
To install Mojolicious, copy and paste the appropriate command in to your terminal.
cpanm Mojolicious
perl -MCPAN -e shell
install Mojolicious
For more information on module installation, please visit the detailed CPAN module installation guide.